@@ -8,6 +8,8 @@ __all__ = ["seg",
     "sigmoid",
     "cosine",
     "any2unicode",
+    "np",
+    "v",
     "__version__"]
 
 from .word2vec import *
